/* Bluetooth stack headers */
#include "bg_types.h"
#include "native_gecko.h"
#include "gatt_db.h"

#include "app.h"
#define TIMER_ID	1

void setAdvScanData(void);

typedef struct
{
	uint8_t len_flags;
	uint8_t type_flags;
	uint8_t val_flags;

	uint8_t len_manuf;
	uint8_t type_manuf;
	uint8_t company_LO;
	uint8_t company_HI;
	char    manuf_name[12];
} customAdv_t;

typedef struct
{
	uint8_t len_name;
	uint8_t type_name;
	char    name[10];
} customScanResp_t;

customAdv_t advData;
customScanResp_t scanData;
uint8_t counter;


/* Main application */
void appMain(gecko_configuration_t *pconfig)
{
#if DISABLE_SLEEP > 0
  pconfig->sleep.flags = 0;
#endif

  /* Initialize debug prints. Note: debug prints are off by default. See DEBUG_LEVEL in app.h */
  initLog();
  setAdvScanData();

  /* Initialize stack */
  gecko_init(pconfig);

  while (1) {
    /* Event pointer for handling events */
    struct gecko_cmd_packet* evt;

    /* if there are no events pending then the next call to gecko_wait_event() may cause
     * device go to deep sleep. Make sure that debug prints are flushed before going to sleep */
    if (!gecko_event_pending()) {
      flushLog();
    }

    /* Check for stack event. This is a blocking event listener. If you want non-blocking please see UG136. */
    evt = gecko_wait_event();

    /* Handle events */
    switch (BGLIB_MSG_ID(evt->header)) {
      /* This boot event is generated when the system boots up after reset.
       * Do not call any stack commands before receiving the boot event.
       * Here the system is set to start advertising immediately after boot procedure. */
      case gecko_evt_system_boot_id:
        /* Set advertising parameters. 100ms advertisement interval.
         * The first parameter is advertising set handle
         * The next two parameters are minimum and maximum advertising interval, both in
         * units of (milliseconds * 1.6).
         * The last two parameters are duration and maxevents left as default. */
        gecko_cmd_le_gap_set_advertise_timing(0, 160, 160, 0, 0);
        gecko_cmd_system_set_tx_power(0);								// set max Tx power (0 dBm)
        gecko_cmd_le_gap_bt5_set_adv_data(0, 0, sizeof(advData), (const uint8_t*)&advData);	// set avd. data
        gecko_cmd_le_gap_bt5_set_adv_data(0, 1, sizeof(scanData), (const uint8_t*)&scanData);	// set scan response data
        /* Start general advertising and enable connections. */
        gecko_cmd_le_gap_start_advertising(0, le_gap_user_data, le_gap_scannable_non_connectable);
        gecko_cmd_hardware_set_soft_timer(32768, TIMER_ID, 0);
      break;

      case gecko_evt_hardware_soft_timer_id:
    	  if (evt->data.evt_hardware_soft_timer.handle == TIMER_ID) {
    		  counter++;
    		  if (counter == 100)
    			  counter = 0;
    		  printLog("%02X\n\r", counter);
    		  scanData.name[8] = (counter / 10) + '0';		// modify the beacon data
    		  scanData.name[9] = (counter % 10) + '0';
    		  gecko_cmd_le_gap_bt5_set_adv_data(0, 1, sizeof(scanData), (const uint8_t*)&scanData);
    	  }
      break;

      default:
      break;
    }
  }
}

void setAdvScanData(void)
{
	advData.len_flags = 0x02;
	advData.type_flags = 0x01;
	advData.val_flags = 0x06;					// general discoverable mode

	advData.len_manuf = 15;
	advData.type_manuf = 0xFF;
	advData.company_LO = 0xFF;					// Silabs company ID (0x02FF)
	advData.company_HI = 0x02;
	strncpy(advData.manuf_name, "Silicon Labs", 12);

	scanData.len_name = 11;
	scanData.type_name = 9;						// full device name
	strncpy(scanData.name, "CSCI470 ??", 10);
}
